seqtools.iterate_sequence_forward_and_backward_nonoverlapping
=============================================================

.. autofunction:: abjad.tools.seqtools.iterate_sequence_forward_and_backward_nonoverlapping
